@@ -4,20 +4,18 @@
 # Copyright (c) Jupyter Development Team.
 # Distributed under the terms of the Modified BSD License.
 
+import json
+import os.path as osp
 from glob import iglob
 from itertools import chain
-import json
 from os.path import join as pjoin
-import os.path as osp
-import os
 
-from jupyter_core.paths import jupyter_path, jupyter_config_dir, SYSTEM_CONFIG_PATH
+from jupyter_core.paths import SYSTEM_CONFIG_PATH, jupyter_config_dir, jupyter_path
 from jupyter_server.services.config.manager import ConfigManager, recursive_update
 from traitlets import Bool, HasTraits, List, Unicode, default
 
 from .server import url_path_join as ujoin
 
-
 # -----------------------------------------------------------------------------
 # Module globals
 # -----------------------------------------------------------------------------
@@ -25,6 +23,19 @@ from .server import url_path_join as ujoin
 DEFAULT_TEMPLATE_PATH = osp.join(osp.dirname(__file__), 'templates')
 
 
+def get_package_url(data):
+    """Get the url from the extension data
+    """
+    # homepage, repository  are optional
+    if 'homepage' in data:
+        url = data['homepage']
+    elif 'repository' in data and isinstance(data['repository'], dict):
+        url = data['repository'].get('url', '')
+    else:
+        url = ''
+    return url
+
+
 def get_federated_extensions(labextensions_path):
     """Get the metadata about federated extensions
     """
@@ -39,6 +50,8 @@ def get_federated_extensions(labextensions_path):
                 data = dict(
                     name=pkgdata['name'],
                     version=pkgdata['version'],
+                    description=pkgdata.get('description', ''),
+                    url=get_package_url(pkgdata),
                     ext_dir=ext_dir,
                     ext_path=osp.dirname(ext_path),
                     is_local=False,
@@ -56,8 +69,8 @@ def get_federated_extensions(labextensions_path):
 def get_static_page_config(app_settings_dir=None, logger=None, level='all'):
     """Get the static page config for JupyterLab
 
-    Params
-    ------
+    Parameters
+    ----------
     logger: logger, optional
         An optional logging object
     level: string, optional ['all']
@@ -172,66 +185,66 @@ def write_page_config(page_config, level='all'):
 class LabConfig(HasTraits):
     """The lab application configuration object.
     """
-    app_name = Unicode('', help='The name of the application.')
+    app_name = Unicode('', help='The name of the application.').tag(config=True)
 
-    app_version = Unicode('', help='The version of the application.')
+    app_version = Unicode('', help='The version of the application.').tag(config=True)
 
-    app_namespace = Unicode('', help='The namespace of the application.')
+    app_namespace = Unicode('', help='The namespace of the application.').tag(config=True)
 
-    app_url = Unicode('/lab', help='The url path for the application.')
+    app_url = Unicode('/lab', help='The url path for the application.').tag(config=True)
 
-    app_settings_dir = Unicode('', help='The application settings directory.')
+    app_settings_dir = Unicode('', help='The application settings directory.').tag(config=True)
 
     extra_labextensions_path = List(Unicode(),
         help="""Extra paths to look for federated JupyterLab extensions"""
-    )
+    ).tag(config=True)
 
-    labextensions_path = List(Unicode(), help='The standard paths to look in for federated JupyterLab extensions')
+    labextensions_path = List(Unicode(), help='The standard paths to look in for federated JupyterLab extensions').tag(config=True)
 
-    templates_dir = Unicode('', help='The application templates directory.')
+    templates_dir = Unicode('', help='The application templates directory.').tag(config=True)
 
     static_dir = Unicode('',
                          help=('The optional location of local static files. '
                                'If given, a static file handler will be '
-                               'added.'))
+                               'added.')).tag(config=True)
 
 
-    labextensions_url = Unicode('', help='The url for federated JupyterLab extensions')
+    labextensions_url = Unicode('', help='The url for federated JupyterLab extensions').tag(config=True)
 
-    settings_url = Unicode(help='The url path of the settings handler.')
+    settings_url = Unicode(help='The url path of the settings handler.').tag(config=True)
 
     user_settings_dir = Unicode('',
                                 help=('The optional location of the user '
-                                      'settings directory.'))
+                                      'settings directory.')).tag(config=True)
 
     schemas_dir = Unicode('',
                           help=('The optional location of the settings '
                                 'schemas directory. If given, a handler will '
-                                'be added for settings.'))
+                                'be added for settings.')).tag(config=True)
 
-    workspaces_api_url = Unicode(help='The url path of the workspaces API.')
+    workspaces_api_url = Unicode(help='The url path of the workspaces API.').tag(config=True)
 
     workspaces_dir = Unicode('',
                              help=('The optional location of the saved '
                                    'workspaces directory. If given, a handler '
-                                   'will be added for workspaces.'))
+                                   'will be added for workspaces.')).tag(config=True)
 
-    listings_url = Unicode(help='The listings url.')
+    listings_url = Unicode(help='The listings url.').tag(config=True)
 
-    themes_url = Unicode(help='The theme url.')
+    themes_url = Unicode(help='The theme url.').tag(config=True)
 
     themes_dir = Unicode('',
                          help=('The optional location of the themes '
                                'directory. If given, a handler will be added '
-                               'for themes.'))
+                               'for themes.')).tag(config=True)
 
-    translations_api_url = Unicode(help='The url path of the translations handler.')
+    translations_api_url = Unicode(help='The url path of the translations handler.').tag(config=True)
 
-    tree_url = Unicode(help='The url path of the tree handler.')
+    tree_url = Unicode(help='The url path of the tree handler.').tag(config=True)
 
     cache_files = Bool(True,
                        help=('Whether to cache files on the server. '
-                             'This should be `True` except in dev mode.'))
+                             'This should be `True` except in dev mode.')).tag(config=True)
 
     @default('template_dir')
     def _default_template_dir(self):
